[llvm-commits] [llvm] r51460 - /llvm/trunk/lib/CodeGen/SelectionDAG/SelectionDAGISel.cpp

Dan Gohman gohman at apple.com
Thu May 22 17:34:05 PDT 2008


Author: djg
Date: Thu May 22 19:34:04 2008
New Revision: 51460

URL: http://llvm.org/viewvc/llvm-project?rev=51460&view=rev
Log:
Use isSingleValueType instead of isFirstClassType to
exclude struct and array types.

Modified:
    llvm/trunk/lib/CodeGen/SelectionDAG/SelectionDAGISel.cpp

Modified: llvm/trunk/lib/CodeGen/SelectionDAG/SelectionDAGISel.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/CodeGen/SelectionDAG/SelectionDAGISel.cpp?rev=51460&r1=51459&r2=51460&view=diff

==============================================================================
--- llvm/trunk/lib/CodeGen/SelectionDAG/SelectionDAGISel.cpp (original)
+++ llvm/trunk/lib/CodeGen/SelectionDAG/SelectionDAGISel.cpp Thu May 22 19:34:04 2008
@@ -3937,9 +3937,9 @@
         if (OpInfo.isIndirect)
           OpTy = cast<PointerType>(OpTy)->getElementType();
 
         // If OpTy is not a first-class value, it may be a struct/union that we
         // can tile with integers.
-        if (!OpTy->isFirstClassType() && OpTy->isSized()) {
+        if (!OpTy->isSingleValueType() && OpTy->isSized()) {
           unsigned BitSize = TD->getTypeSizeInBits(OpTy);
           switch (BitSize) {
           default: break;
@@ -3937,9 +3937,9 @@
           OpTy = cast<PointerType>(OpTy)->getElementType();
 
-        // If OpTy is not a first-class value, it may be a struct/union that we
+        // If OpTy is not a single value, it may be a struct/union that we
         // can tile with integers.





More information about the llvm-commits mailing list